@@ -1,16 +1,16 @@
 package Data::Validation::Constraints::Path;
 
-# @(#)$Id: Path.pm 56 2008-09-05 22:37:26Z pjf $
+# @(#)$Id: Path.pm 57 2008-09-15 18:48:07Z pjf $
 
 use strict;
 use Moose;
 
-use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 56 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 57 $ =~ /\d+/gmx );
 
 extends 'Data::Validation::Constraints';
 
 override '_validate' => sub {
-   my ($me, $val) = @_; return $val =~ m{ [;&*{} ] }mx ? 0 : 1;
+   my ($self, $val) = @_; return $val =~ m{ [;&*{} ] }mx ? 0 : 1;
 };
 
 1;
